[![pdm-managed](https://img.shields.io/badge/pdm-managed-blueviolet)](https://dev.to/frostming/a-review-pipenv-vs-poetry-vs-pdm-39b4)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Python](https://img.shields.io/badge/python-3.8-green)]()
[![Doc](https://ydethe.gitlab.io/pikendus-backend/doc_badge.svg)](https://ydethe.gitlab.io/pikendus-backend/)
[![Coverage](https://ydethe.gitlab.io/pikendus-backend/cov_badge.svg)]()

# Quick look

pikendus backend is a PEP517 compliant build backend, able to compile C and fortran source files
pikendus is an estonian word that means 'extension'

# Build the doc

Just run:

    pdm doc

This will create the doc in ./htmldoc

A few guidelines for updating the doc
https://sphinxcontrib-napoleon.readthedocs.io/en/latest/example_google.html
